pub async fn heartbeat(
__arg0: State<ApiState>,
__arg1: Json<HeartbeatRequest>,
) -> ApiResult<Json<HeartbeatResponse>>Expand description
Send a heartbeat to keep the agent registered and prevent timeout disconnection.
pub async fn heartbeat(
__arg0: State<ApiState>,
__arg1: Json<HeartbeatRequest>,
) -> ApiResult<Json<HeartbeatResponse>>Send a heartbeat to keep the agent registered and prevent timeout disconnection.