pub async fn import_device_registrations(
__arg0: State<ApiState>,
__arg1: Path<String>,
__arg2: Json<DeviceRegistrationImportRequest>,
) -> ApiResult<Json<DeviceRegistrationImportResponse>>Expand description
Import device registrations for an agent
Imports a device registration configuration, replacing all existing device registrations for the agent. The configuration must be in the format compatible with ConnectorAgent::set_device_registrations_from_json.
Warning
This operation wipes all existing registered devices before importing the new configuration.