pub struct MemoryCorticalAreaResponse {Show 16 fields
pub cortical_id: String,
pub cortical_idx: u32,
pub cortical_name: String,
pub short_term_neuron_count: usize,
pub long_term_neuron_count: usize,
pub memory_parameters: MemoryCorticalAreaParamsResponse,
pub upstream_cortical_area_indices: Vec<u32>,
pub upstream_cortical_area_count: usize,
pub upstream_pattern_cache_size: usize,
pub incoming_synapse_count: usize,
pub outgoing_synapse_count: usize,
pub total_memory_neuron_ids: usize,
pub page: u32,
pub page_size: u32,
pub memory_neuron_ids: Vec<u64>,
pub has_more: bool,
}Expand description
Response for get_memory_cortical_area.
Fields
cortical_id: Stringcortical_idx: u32cortical_name: Stringshort_term_neuron_count: usizelong_term_neuron_count: usizememory_parameters: MemoryCorticalAreaParamsResponseupstream_cortical_area_indices: Vec<u32>Upstream cortical indices that feed pattern detection for this memory area.
upstream_cortical_area_count: usizeupstream_pattern_cache_size: usizeDistinct temporal patterns cached in the pattern detector for this area.
incoming_synapse_count: usizeoutgoing_synapse_count: usizetotal_memory_neuron_ids: usizepage: u32page_size: u32memory_neuron_ids: Vec<u64>has_more: boolTrait Implementations
Sourceimpl Clone for MemoryCorticalAreaResponse
impl Clone for MemoryCorticalAreaResponse
Sourcefn clone(&self) -> MemoryCorticalAreaResponse
fn clone(&self) -> MemoryCorticalAreaResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MemoryCorticalAreaResponse
impl Debug for MemoryCorticalAreaResponse