FEAGI v1 Physiology API
Endpoints to read/update physiology parameters in the active genome Maps to Python: feagi/api/v1/physiology.py
Functions
- get_
physiology - Get current physiology parameters including simulation timestep and neural aging settings.
- put_
physiology - Update physiology parameters in the active genome including timestep and aging settings.